@@ -10,7 +10,7 @@
 
 #include "AprsPlugin.h"
 
-#include "global.h"
+#include "MarbleGlobal.h"
 #include "MarbleDebug.h"
 
 #include <QtGui/QColor>
@@ -37,13 +37,21 @@ using namespace Marble;
 /* TRANSLATOR Marble::AprsPlugin */
 
 AprsPlugin::AprsPlugin()
-    : m_mutex( new QMutex ),
+    : RenderPlugin( 0 ),
+      m_mutex( 0 ),
+      m_configDialog( 0 ),
+      ui_configWidget( 0 )
+{
+}
+
+AprsPlugin::AprsPlugin( const MarbleModel *marbleModel )
+    : RenderPlugin( marbleModel ),
+      m_mutex( new QMutex ),
       m_initialized( false ),
       m_tcpipGatherer( 0 ),
       m_ttyGatherer( 0 ),
       m_fileGatherer( 0 ),
       m_action( 0 ),
-      m_aboutDialog( 0 ),
       m_configDialog( 0 ),
       ui_configWidget( 0 )
 {
@@ -52,8 +60,8 @@ AprsPlugin::AprsPlugin()
     
     setSettings( QHash<QString,QVariant>() );
 
-    connect( this, SIGNAL( visibilityChanged( QString, bool ) ),
-             this, SLOT( updateVisibility( QString, bool ) ) );
+    connect( this, SIGNAL( visibilityChanged( bool, const QString & ) ),
+             this, SLOT( updateVisibility( bool ) ) );
 
     m_action = new QAction( this );
     connect( m_action,    SIGNAL( toggled( bool ) ),
@@ -80,9 +88,8 @@ AprsPlugin::~AprsPlugin()
     delete m_mutex;
 }
 
-void AprsPlugin::updateVisibility( QString nameId, bool visible )
+void AprsPlugin::updateVisibility( bool visible )
 {
-    Q_UNUSED( nameId );
     if ( visible )
         restartGatherers();
     else
@@ -124,40 +131,32 @@ QString AprsPlugin::nameId() const
     return QString( "aprs-plugin" );
 }
 
+QString AprsPlugin::version() const
+{
+    return "1.0";
+}
+
 QString AprsPlugin::description() const
 {
     return tr( "This plugin displays APRS data gleaned from the Internet.  APRS is an Amateur Radio protocol for broadcasting location and other information." );
 }
 
+QString AprsPlugin::copyrightYears() const
+{
+    return "2009, 2010";
+}
+
+QList<PluginAuthor> AprsPlugin::pluginAuthors() const
+{
+    return QList<PluginAuthor>()
+            << PluginAuthor( "Wes Hardaker", "hardaker@users.sourceforge.net" );
+}
+
 QIcon AprsPlugin::icon () const
 {
     return QIcon();
 }
 
-QDialog* AprsPlugin::aboutDialog()
-{
-    if ( !m_aboutDialog )
-    {
-        // Initializing about dialog
-        m_aboutDialog = new PluginAboutDialog();
-        m_aboutDialog->setName( "APRS Plugin" );
-        m_aboutDialog->setVersion( "0.1" );
-        // FIXME: Can we store this string for all of Marble
-        m_aboutDialog->setAboutText( tr( "<br />(c) 2009, 2010 The Marble Project<br /><br /><a href=\"http://edu.kde.org/marble\">http://edu.kde.org/marble</a>" ) );
-        QList<Author> authors;
-        Author hardaker;
-        
-        hardaker.name = QString::fromUtf8( "Wes Hardaker" );
-        hardaker.task = tr( "Developer" );
-        hardaker.email = "hardaker@users.sourceforge.net";
-        authors.append( hardaker );
-        m_aboutDialog->setAuthors( authors );
-        
-        m_aboutDialog->setLicense( PluginAboutDialog::License_LGPL_V2 );
-    }
-    return m_aboutDialog;
-}
-
 void AprsPlugin::stopGatherers()
 {
 
@@ -351,43 +350,44 @@ QHash<QString,QVariant> AprsPlugin::settings() const
     return m_settings;
 }
 
-void AprsPlugin::setSettings( QHash<QString,QVariant> settings )
+void AprsPlugin::setSettings( const QHash<QString,QVariant> &settings )
 {
+    m_settings = settings;
+
     // Check if all fields are filled and fill them with default values.
     // Information
-    if ( !settings.contains( "useInternet" ) ) {
-        settings.insert( "useInternet", true );
+    if ( !m_settings.contains( "useInternet" ) ) {
+        m_settings.insert( "useInternet", true );
     }
-    if ( !settings.contains( "useTTY" ) ) {
-        settings.insert( "useTTY", false );
+    if ( !m_settings.contains( "useTTY" ) ) {
+        m_settings.insert( "useTTY", false );
     }
 
-    if ( !settings.contains( "APRSHost" ) ) {
-        settings.insert( "APRSHost", "rotate.aprs.net" );
+    if ( !m_settings.contains( "APRSHost" ) ) {
+        m_settings.insert( "APRSHost", "rotate.aprs.net" );
     }
-    if ( !settings.contains( "APRSPort" ) ) {
-        settings.insert( "APRSPort", "10253" );
+    if ( !m_settings.contains( "APRSPort" ) ) {
+        m_settings.insert( "APRSPort", "10253" );
     }
-    if ( !settings.contains( "TNCTTY" ) ) {
-        settings.insert( "TNCTTY", "/dev/ttyUSB0" );
+    if ( !m_settings.contains( "TNCTTY" ) ) {
+        m_settings.insert( "TNCTTY", "/dev/ttyUSB0" );
     }
 
-    if ( !settings.contains( "TCPIPDump" ) ) {
-        settings.insert( "TCPIPDump", false );
+    if ( !m_settings.contains( "TCPIPDump" ) ) {
+        m_settings.insert( "TCPIPDump", false );
     }
-    if ( !settings.contains( "TTYDump" ) ) {
-        settings.insert( "TTYDump", false );
+    if ( !m_settings.contains( "TTYDump" ) ) {
+        m_settings.insert( "TTYDump", false );
     }
 
-    if ( !settings.contains( "fadeTime" ) ) {
-        settings.insert( "fadeTime", 10 );
+    if ( !m_settings.contains( "fadeTime" ) ) {
+        m_settings.insert( "fadeTime", 10 );
     }
 
-    if ( !settings.contains( "hideTime" ) ) {
-        settings.insert( "hideTime", 45 );
+    if ( !m_settings.contains( "hideTime" ) ) {
+        m_settings.insert( "hideTime", 45 );
     }
 
-    m_settings = settings;
     readSettings();
     emit settingsChanged( nameId() );
 }
