@@ -33,8 +33,8 @@ class ProgressFloatItem  : public AbstractFloatItem
     MARBLE_PLUGIN( ProgressFloatItem )
 
  public:
-    explicit ProgressFloatItem ( const QPointF &point = QPointF( -10.5, -150.5 ),
-                                const QSizeF &size = QSizeF( 40.0, 40.0 ) );
+    ProgressFloatItem();
+    explicit ProgressFloatItem( const MarbleModel *marbleModel );
     ~ProgressFloatItem ();
 
     QStringList backendTypes() const;
@@ -45,8 +45,14 @@ class ProgressFloatItem  : public AbstractFloatItem
 
     QString nameId() const;
 
+    QString version() const;
+
     QString description() const;
 
+    QString copyrightYears() const;
+
+    QList<PluginAuthor> pluginAuthors() const;
+
     QIcon icon () const;
 
     void initialize ();
@@ -61,11 +67,11 @@ class ProgressFloatItem  : public AbstractFloatItem
     bool eventFilter(QObject *object, QEvent *e);
 
 private Q_SLOTS:
-    void addProgressItem();
-
     void removeProgressItem();
 
-    void resetProgress();
+    void handleProgress( int active, int queued );
+
+    void hideProgress();
 
     void show();
 
@@ -84,7 +90,7 @@ private Q_SLOTS:
 
     int m_completedJobs;
 
-    QTimer m_progressResetTimer;
+    QTimer m_progressHideTimer;
 
     QTimer m_progressShowTimer;
 
