@@ -29,6 +29,7 @@
 #include "routing/RoutingManager.h"
 #include "routing/RoutingModel.h"
 #include "routing/RouteRequest.h"
+#include "routing/SpeakersModel.h"
 #include "ViewportParams.h"
 #include "WidgetGraphicsItem.h"
 
@@ -66,6 +67,7 @@ public:
     QDialog *m_configDialog;
     Ui::RoutingConfigDialog m_configUi;
     bool m_routeCompleted;
+    SpeakersModel* m_speakersModel;
 
     RoutingPluginPrivate( RoutingPlugin* parent );
 
@@ -112,12 +114,13 @@ RoutingPluginPrivate::RoutingPluginPrivate( RoutingPlugin *parent ) :
     m_audio( new AudioOutput( parent ) ),
     m_configDialog( 0 ),
     m_routeCompleted( false ),
+    m_speakersModel( 0 ),
     m_parent( parent )
 
 {
     m_settings["muted"] = false;
     m_settings["sound"] = true;
-    m_settings["speaker"] = QString();
+    m_settings["speaker"].clear();
 }
 
 QString RoutingPluginPrivate::richText( const QString &source ) const
@@ -271,7 +274,6 @@ void RoutingPluginPrivate::toggleGuidanceMode( bool enabled )
 
     if ( enabled ) {
         m_routeCompleted = false;
-        m_audio->announceStart();
     }
 
     forceRepaint();
@@ -282,7 +284,7 @@ void RoutingPluginPrivate::updateDestinationInformation()
     if ( m_routingModel->route().currentSegment().isValid() ) {
         qreal remaining = remainingDistance();
         qreal distanceLeft = nextInstructionDistance();
-        m_audio->update( m_routingModel->route(), distanceLeft );
+        m_audio->update( m_routingModel->route(), distanceLeft, remaining, m_routingModel->deviatedFromRoute() );
 
         m_nearNextInstruction = distanceLeft < thresholdDistance;
 
@@ -322,7 +324,6 @@ void RoutingPluginPrivate::updateDestinationInformation()
                 m_routeCompleted = false;
             } else {
                 if ( !m_routeCompleted ) {
-                    m_audio->announceDestination();
                     QString content = QObject::tr( "Arrived at destination. <a href=\"#reverse\">Calculate the way back.</a>" );
                     m_widget.instructionLabel->setText( richText( "%1" ).arg( content ) );
                 }
@@ -345,11 +346,10 @@ void RoutingPluginPrivate::togglePositionTracking( bool enabled )
     PositionProviderPlugin* plugin = 0;
     if ( enabled ) {
         const PluginManager* pluginManager = m_marbleWidget->model()->pluginManager();
-        QList<PositionProviderPlugin*> plugins = pluginManager->createPositionProviderPlugins();
+        QList<const PositionProviderPlugin*> plugins = pluginManager->positionProviderPlugins();
         if ( plugins.size() > 0 ) {
-            plugin = plugins.takeFirst();
+            plugin = plugins.first()->newInstance();
         }
-        qDeleteAll( plugins );
     }
     m_parent->marbleModel()->positionTracking()->setPositionProviderPlugin( plugin );
 }
@@ -371,15 +371,11 @@ void RoutingPluginPrivate::readSettings()
     m_audio->setSpeaker( speaker );
 
     if ( m_configDialog ) {
-        QStringList const speakerPaths = m_audio->speakers();
-        QStringList speakers;
-        foreach( const QString &speaker, speakerPaths ) {
-            speakers << QFileInfo( speaker ).fileName();
+        if ( !m_speakersModel ) {
+            m_speakersModel = new SpeakersModel( m_parent );
         }
-
-        int const index = speakerPaths.indexOf( speaker );
-        m_configUi.speakerComboBox->clear();
-        m_configUi.speakerComboBox->addItems( speakers );
+        int const index = m_speakersModel->indexOf( speaker );
+        m_configUi.speakerComboBox->setModel( m_speakersModel );
         m_configUi.speakerComboBox->setCurrentIndex( index );
         m_configUi.voiceNavigationCheckBox->setChecked( !muted );
         m_configUi.soundRadioButton->setChecked( sound );
@@ -422,10 +418,13 @@ qreal RoutingPluginPrivate::remainingDistance() const
 void RoutingPlugin::writeSettings()
 {
     Q_ASSERT( d->m_configDialog );
-    QStringList const speakerPaths = d->m_audio->speakers();
     int const index = d->m_configUi.speakerComboBox->currentIndex();
-    if ( index >= 0 && index < speakerPaths.size() ) {
-        d->m_settings["speaker"] = speakerPaths.at( index );
+    if ( index >= 0 ) {
+        QModelIndex const idx = d->m_speakersModel->index( index );
+        d->m_settings["speaker"] = d->m_speakersModel->data( idx, SpeakersModel::Path );
+        if ( !d->m_speakersModel->data( idx, SpeakersModel::IsLocal ).toBool() ) {
+            d->m_speakersModel->install( index );
+        }
     }
     d->m_settings["muted"] = !d->m_configUi.voiceNavigationCheckBox->isChecked();
     d->m_settings["sound"] = d->m_configUi.soundRadioButton->isChecked();
@@ -434,8 +433,14 @@ void RoutingPlugin::writeSettings()
 }
 
 
-RoutingPlugin::RoutingPlugin( const QPointF &position ) :
-    AbstractFloatItem( position ),
+RoutingPlugin::RoutingPlugin() :
+    AbstractFloatItem( 0 ),
+    d( 0 )
+{
+}
+
+RoutingPlugin::RoutingPlugin( const MarbleModel *marbleModel ) :
+    AbstractFloatItem( marbleModel, QPointF( -10, -10 ) ),
     d( new RoutingPluginPrivate( this ) )
 {
     setEnabled( true );
@@ -471,11 +476,28 @@ QString RoutingPlugin::nameId() const
     return QString( "routing" );
 }
 
+QString RoutingPlugin::version() const
+{
+    return "1.0";
+}
+
 QString RoutingPlugin::description() const
 {
     return tr( "Routing information and navigation controls" );
 }
 
+QString RoutingPlugin::copyrightYears() const
+{
+    return "2010";
+}
+
+QList<PluginAuthor> RoutingPlugin::pluginAuthors() const
+{
+    return QList<PluginAuthor>()
+            << PluginAuthor( "Siddharth Srivastava", "akssps011@gmail.com" )
+            << PluginAuthor( QString::fromUtf8( "Dennis Nienhüser" ), "earthwings@gentoo.org" );
+}
+
 QIcon RoutingPlugin::icon() const
 {
     return QIcon();
@@ -556,7 +578,7 @@ QHash<QString,QVariant> RoutingPlugin::settings() const
     return d->m_settings;
 }
 
-void RoutingPlugin::setSettings( QHash<QString,QVariant> settings )
+void RoutingPlugin::setSettings( const QHash<QString,QVariant> &settings )
 {
     d->m_settings = settings;
     if (!d->m_settings.contains("muted")) {
