@@ -32,10 +32,13 @@ namespace gpx
     extern const char* gpxTag_nameSpace10;
     extern const char* gpxTag_nameSpace11;
 
+    extern const char* gpxTag_ele;
+    extern const char* gpxTag_extensions;
     extern const char* gpxTag_gpx;
     extern const char* gpxTag_lat;
     extern const char* gpxTag_lon;
     extern const char* gpxTag_name;
+    extern const char* gpxTag_time;
     extern const char* gpxTag_trk;
     extern const char* gpxTag_trkpt;
     extern const char* gpxTag_trkseg;
@@ -43,11 +46,16 @@ namespace gpx
     extern const char* gpxTag_rte;
     extern const char* gpxTag_rtept;
     // TODO: add all remaining tags!
+
+    extern const char* gpxTag_nameSpaceGarminTrackPointExt1;
+    extern const char* gpxTag_TrackPointExtension;
+    extern const char* gpxTag_hr;
 }
 
 // Helper macros
 #define GPX_DEFINE_TAG_HANDLER_10(Name) GEODATA_DEFINE_TAG_HANDLER(gpx, GPX, Name, gpxTag_nameSpace10)
 #define GPX_DEFINE_TAG_HANDLER_11(Name) GEODATA_DEFINE_TAG_HANDLER(gpx, GPX, Name, gpxTag_nameSpace11)
+#define GPX_DEFINE_TAG_HANDLER_GARMIN_TRACKPOINTEXT1(Name) GEODATA_DEFINE_TAG_HANDLER(gpx, GPX, Name, gpxTag_nameSpaceGarminTrackPointExt1)
 
 #define GPX_DEFINE_TAG_HANDLER(Name) \
     GPX_DEFINE_TAG_HANDLER_10(Name) \
